The functions listed here are deprecated. This means that they once existed in earlier versions of the of the prioritizrdata package, but they have since been removed entirely, replaced by other functions, or renamed as other functions in newer versions. To help make it easier to transition to new versions of the prioritizrdata package, we have listed alternatives for deprecated the functions (where applicable). If a function is described as being renamed, then this means that only the name of the function has changed (i.e., the inputs, outputs, and underlying code remain the same).
Details
The following functions have been deprecated:
get_wa_features()renamed as the
get_wa_species()function.